@@ -142,6 +142,26 @@ class Tariff(object):
 
         return True
 
+    def evaluate_powers_all_checks(self, powers):
+        """
+
+        :param powers: [pow1, pow2,...]
+        :return: [Error1, Error2] if errors else []
+        """
+        errors = []
+        if min(powers) <= 0:
+            errors.append(NotPositivePower())
+        if not len(self.power_periods) == len(powers):
+            errors.append(IncorrectPowerNumber(len(powers), len(self.power_periods)))
+        if not self.is_maximum_power_correct(max(powers)):
+            errors.append(IncorrectMaxPower(max(powers), self.min_power, self.max_power))
+        if not self.is_minimum_powers_correct(min(powers)):
+            errors.append(IncorrectMinPower(min(powers), self.min_power, self.max_power))
+        if not self.are_powers_normalized(powers):
+            errors.append(NotNormalizedPower())
+
+        return errors
+
     def evaluate_powers(self, powers):
         if min(powers) <= 0:
             raise NotPositivePower()
@@ -501,6 +521,13 @@ class T31A(T30A):
 
         return True
 
+    def evaluate_powers_all_checks(self, powers):
+        errors = super(T31A, self).evaluate_powers_all_checks(powers)
+        if not are_powers_ascending(powers):
+            errors.append(NotAscendingPowers())
+
+        return errors
+
 
 class T31A_one_period(T31A):
     """
@@ -599,6 +626,13 @@ class T61A(Tariff):
 
         return True
 
+    def evaluate_powers_all_checks(self, powers):
+        errors = super(T61A, self).evaluate_powers_all_checks(powers)
+        if not are_powers_ascending(powers):
+            errors.append(NotAscendingPowers())
+
+        return errors
+
 
 class T61B(T61A):
     """
